@@ -1,4 +1,4 @@
-from asgiref.typing import (
+from uvicorn._types import (
     ASGI2Application,
     ASGIReceiveCallable,
     ASGISendCallable,
@@ -7,11 +7,11 @@ from asgiref.typing import (
 
 
 class ASGI2Middleware:
-    def __init__(self, app: ASGI2Application):
+    def __init__(self, app: "ASGI2Application"):
         self.app = app
 
     async def __call__(
-        self, scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable
+        self, scope: "Scope", receive: "ASGIReceiveCallable", send: "ASGISendCallable"
     ) -> None:
         instance = self.app(scope)
         await instance(receive, send)
